.. _mathematical_helper_functions:

Mathematical helper functions
#############################

.. automodule:: maicos.lib.math
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: maicos.lib._cmath
    :members:
    :undoc-members:
    :show-inheritance:
